@@ -16,6 +16,7 @@ import os
 
 from eventlet.green import socket
 from oslo_config import cfg
+from oslo_db import options as oslo_db_ops
 from oslo_log import log as logging
 from oslo_middleware import cors
 from osprofiler import opts as profiler
@@ -60,6 +61,13 @@ service_opts = [
                       'SSL is used.')),
     cfg.StrOpt('region_name_for_services',
                help=_('Default region name used to get services endpoints.')),
+    cfg.StrOpt('region_name_for_shared_services',
+               help=_('Region name for shared services endpoints.')),
+    cfg.ListOpt('shared_services_types',
+                default=['image', 'volume', 'volumev2'],
+                help=_('The shared services located in the other region.'
+                       'Needs region_name_for_shared_services option to '
+                       'be set for this to take effect.')),
     cfg.StrOpt('heat_stack_user_role',
                default="heat_stack_user",
                help=_('Keystone role for heat template-defined users.')),
@@ -88,7 +96,14 @@ service_opts = [
     cfg.IntOpt('num_engine_workers',
                help=_('Number of heat-engine processes to fork and run. '
                       'Will default to either to 4 or number of CPUs on '
-                      'the host, whichever is greater.'))]
+                      'the host, whichever is greater.')),
+    cfg.StrOpt('server_keystone_endpoint_type',
+               choices=['', 'public', 'internal', 'admin'],
+               default='',
+               help=_('If set, is used to control which authentication '
+                      'endpoint is used by user-controlled servers to make '
+                      'calls back to Heat. '
+                      'If unset www_authenticate_uri is used.'))]
 
 engine_opts = [
     cfg.ListOpt('plugin_dirs',
@@ -117,6 +132,18 @@ engine_opts = [
                help=_('Allow reauthentication on token expiry, such that'
                       ' long-running tasks may complete. Note this defeats'
                       ' the expiry of any provided user tokens.')),
+    cfg.BoolOpt('allow_trusts_redelegation',
+                default=False,
+                help=_('Create trusts with redelegation enabled. '
+                       'This option is only used when '
+                       'reauthentication_auth_method is set to "trusts". '
+                       'Note that enabling this option does have '
+                       'security implications as all trusts created by Heat '
+                       'will use both impersonation and redelegation enabled. '
+                       'Enable it only when there are other services that '
+                       'need to create trusts from tokens Heat uses to '
+                       'access them, examples are Aodh and Heat in another '
+                       'region when configured to use trusts too.')),
     cfg.ListOpt('trusts_delegated_roles',
                 default=[],
                 help=_('Subset of trustor roles to be delegated to heat.'
@@ -127,9 +154,9 @@ engine_opts = [
                help=_('Maximum resources allowed per top-level stack. '
                       '-1 stands for unlimited.')),
     cfg.IntOpt('max_stacks_per_tenant',
-               default=100,
-               help=_('Maximum number of stacks any one tenant may have'
-                      ' active at one time.')),
+               default=512,
+               help=_('Maximum number of stacks any one tenant may have '
+                      'active at one time. -1 stands for unlimited.')),
     cfg.IntOpt('action_retry_limit',
                default=5,
                help=_('Number of times to retry to bring a '
@@ -157,6 +184,11 @@ engine_opts = [
                         'this limitation, any nova feature supported with '
                         'microversion number above max_nova_api_microversion '
                         'will not be available.')),
+    cfg.FloatOpt('max_ironic_api_microversion',
+                 help=_('Maximum ironic API version for client plugin. With '
+                        'this limitation, any ironic feature supported with '
+                        'microversion number above '
+                        'max_ironic_api_microversion will not be available.')),
     cfg.IntOpt('event_purge_batch_size',
                min=1,
                default=200,
@@ -429,7 +461,7 @@ def list_opts():
     for client in ('aodh', 'barbican', 'cinder', 'designate',
                    'glance', 'heat', 'keystone', 'magnum', 'manila', 'mistral',
                    'monasca', 'neutron', 'nova', 'octavia', 'sahara', 'senlin',
-                   'swift', 'trove', 'zaqar'
+                   'swift', 'trove', 'vitrage', 'zaqar'
                    ):
         client_specific_group = 'clients_' + client
         yield client_specific_group, clients_opts
@@ -438,6 +470,7 @@ def list_opts():
     yield 'clients_keystone', keystone_client_opts
     yield 'clients_nova', client_http_log_debug_opts
     yield 'clients_cinder', client_http_log_debug_opts
+    yield oslo_db_ops.list_opts()[0]
 
 
 cfg.CONF.register_group(paste_deploy_group)
